#
# spec file for package python-plaster
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-plaster
Version:        1.1.2
Release:        3.3
Summary:        A loader interface around multiple config file formats
License:        MIT
Group:          Development/Languages/Python
URL:            http://docs.pylonsproject.org/projects/plaster/en/latest
# The _service download the source and repack without the docs folder
# that has CC noncommercial license.
Source:         plaster-%{version}.tar.xz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Plaster is a loader interface around multiple config file formats.
It exists to define a common API for applications to use when they
wish to load a configuration. The library itself does not aim to
handle anything except a basic API that applications may use to find
and load configuration settings. Any specific constraints should be
implemented in a pluggable loader which can be registered via an
entrypoint.

%prep
%autosetup -p1 -n plaster-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license %{python_sitelib}/plaster-%{version}.dist-info/LICENSE.txt
%{python_sitelib}/plaster-%{version}.dist-info/
%{python_sitelib}/plaster/

%changelog
* Tue May 14 2024 Daniel Garcia <daniel.garcia@suse.com>
- Build from source, using obs_scm service to download from repository
  without docs/* to do not distribute CC-noncomercial licensed
  documentation.
* Fri Jun  9 2023 ecsos <ecsos@popensuse.org>
- Add %%{?sle15_python_module_pythons}
* Wed Dec  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.1.2
  Fix a bug in which plaster would crash harder than expected if a URI is specified to a distribution that does not have the specified entry points.
  Now a LoaderNotFound exception will be raised instead of a bad unpacking of tuples.
- Update to version 1.1.1
  * Add support for Python 3.11.
  * Fix an bug introduced in 1.1 on some systems where plaster.exceptions.MultipleLoadersFound would be raised due to lib and lib64 being symlinked
    to each other and both added to the sys.path. See https://github.com/Pylons/plaster/pull/27
- Update to version 1.1
  * Drop support for Python 2.7, 3.4, 3.5, 3.6.
  * Add support for Python 3.8, 3.9, 3.10.
  * Drop runtime dependency on setuptools / pkg_resources by switching to importlib.metadata.
* Sat Jan 11 2020 Bernhard Wiedemann <bwiedemann@suse.com>
- Use pyproject_install macro (boo#1094323)
* Sun May 19 2019 Todd R <toddrme2178@gmail.com>
- Switch to wheel, which doesn't have the problematic
  CC-noncomercial licensed documentation.
* Wed Apr 24 2019 pgajdos@suse.com
- version update to 1.0
  * improve the exception message for ``InvalidURI`` to show the ``config_uri``.
  See https://github.com/Pylons/plaster/pull/17
* Fri Jul 14 2017 aloisio@gmx.com
- Initial package (0.5)
